pub struct EntityLink {
pub kind: String,
pub value: String,
pub file_range: Option<FileRange>,
pub confidence: Confidence,
}Fields
kind: Stringvalue: Stringfile_range: Option<FileRange>confidence: ConfidenceTrait Implementations
Sourceimpl Clone for EntityLink
impl Clone for EntityLink
Sourcefn clone(&self) -> EntityLink
fn clone(&self) -> EntityLink
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntityLink
impl Debug for EntityLink
Sourceimpl<'de> Deserialize<'de> for EntityLink
impl<'de> Deserialize<'de> for EntityLink
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EntityLink
impl JsonSchema for EntityLink
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EntityLink
impl RefUnwindSafe for EntityLink
impl Send for EntityLink
impl Sync for EntityLink
impl Unpin for EntityLink
impl UnsafeUnpin for EntityLink
impl UnwindSafe for EntityLink