pub struct GitFileTouch {
pub id: HistoryRecordId,
pub commit_id: GitCommitId,
pub path: PathBuf,
pub previous_path: Option<PathBuf>,
pub change_kind: GitChangeKind,
pub additions: Option<u32>,
pub deletions: Option<u32>,
pub touched_at: DateTime<Utc>,
}Fields
id: HistoryRecordIdcommit_id: GitCommitIdpath: PathBufprevious_path: Option<PathBuf>change_kind: GitChangeKindadditions: Option<u32>deletions: Option<u32>touched_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for GitFileTouch
impl Clone for GitFileTouch
Sourcefn clone(&self) -> GitFileTouch
fn clone(&self) -> GitFileTouch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitFileTouch
impl Debug for GitFileTouch
Sourceimpl<'de> Deserialize<'de> for GitFileTouch
impl<'de> Deserialize<'de> for GitFileTouch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GitFileTouch
Sourceimpl JsonSchema for GitFileTouch
impl JsonSchema for GitFileTouch
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GitFileTouch
impl PartialEq for GitFileTouch
Sourcefn eq(&self, other: &GitFileTouch) -> bool
fn eq(&self, other: &GitFileTouch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GitFileTouch
impl Serialize for GitFileTouch
impl StructuralPartialEq for GitFileTouch