pub struct GraphEdge {
pub id: EdgeId,
pub from: NodeId,
pub to: NodeId,
pub edge_type: GraphEdgeType,
pub evidence: Evidence,
pub properties: BTreeMap<String, Value>,
pub schema_version: Option<String>,
pub source_pass: Option<String>,
pub index_mode: Option<String>,
pub extractor_version: Option<String>,
pub ambiguity: Vec<String>,
pub quality_notes: Vec<String>,
}Fields
id: EdgeIdfrom: NodeIdto: NodeIdedge_type: GraphEdgeTypeevidence: Evidenceproperties: BTreeMap<String, Value>schema_version: Option<String>source_pass: Option<String>index_mode: Option<String>extractor_version: Option<String>ambiguity: Vec<String>quality_notes: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for GraphEdge
impl<'de> Deserialize<'de> for GraphEdge
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GraphEdge
impl JsonSchema for GraphEdge
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GraphEdge
impl RefUnwindSafe for GraphEdge
impl Send for GraphEdge
impl Sync for GraphEdge
impl Unpin for GraphEdge
impl UnsafeUnpin for GraphEdge
impl UnwindSafe for GraphEdge