pub struct MemoryFact {
pub id: MemoryFactId,
pub text: String,
pub source: String,
pub confidence: Confidence,
pub entities: Vec<EntityLink>,
pub created_at: DateTime<Utc>,
}Fields
id: MemoryFactIdtext: Stringsource: Stringconfidence: Confidenceentities: Vec<EntityLink>created_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for MemoryFact
impl Clone for MemoryFact
Sourcefn clone(&self) -> MemoryFact
fn clone(&self) -> MemoryFact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemoryFact
impl Debug for MemoryFact
Sourceimpl<'de> Deserialize<'de> for MemoryFact
impl<'de> Deserialize<'de> for MemoryFact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MemoryFact
impl JsonSchema for MemoryFact
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MemoryFact
impl RefUnwindSafe for MemoryFact
impl Send for MemoryFact
impl Sync for MemoryFact
impl Unpin for MemoryFact
impl UnsafeUnpin for MemoryFact
impl UnwindSafe for MemoryFact